# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/devices/device.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.devices import component_pb2 as ubii_dot_proto__v2_dot_types_dot_devices_dot_component__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/devices/device.proto',
  package='ubii.proto_v2.types.devices',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(ubii/proto_v2/types/devices/device.proto\x12\x1bubii.proto_v2.types.devices\x1a+ubii/proto_v2/types/devices/component.proto\"\x85\x02\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x43\n\x0b\x64\x65vice_type\x18\x03 \x01(\x0e\x32..ubii.proto_v2.types.devices.Device.DeviceType\x12:\n\ncomponents\x18\x04 \x03(\x0b\x32&.ubii.proto_v2.types.devices.Component\x12\x11\n\tclient_id\x18\x05 \x01(\t\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\"*\n\nDeviceType\x12\x0f\n\x0bPARTICIPANT\x10\x00\x12\x0b\n\x07WATCHER\x10\x01\"C\n\nDeviceList\x12\x35\n\x08\x65lements\x18\x01 \x03(\x0b\x32#.ubii.proto_v2.types.devices.Deviceb\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_devices_dot_component__pb2.DESCRIPTOR,])



_DEVICE_DEVICETYPE = _descriptor.EnumDescriptor(
  name='DeviceType',
  full_name='ubii.proto_v2.types.devices.Device.DeviceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WATCHER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=338,
  serialized_end=380,
)
_sym_db.RegisterEnumDescriptor(_DEVICE_DEVICETYPE)


_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='ubii.proto_v2.types.devices.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.devices.Device.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.devices.Device.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='ubii.proto_v2.types.devices.Device.device_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='components', full_name='ubii.proto_v2.types.devices.Device.components', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='ubii.proto_v2.types.devices.Device.client_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.devices.Device.tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.devices.Device.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICE_DEVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=380,
)


_DEVICELIST = _descriptor.Descriptor(
  name='DeviceList',
  full_name='ubii.proto_v2.types.devices.DeviceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.devices.DeviceList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=449,
)

_DEVICE.fields_by_name['device_type'].enum_type = _DEVICE_DEVICETYPE
_DEVICE.fields_by_name['components'].message_type = ubii_dot_proto__v2_dot_types_dot_devices_dot_component__pb2._COMPONENT
_DEVICE_DEVICETYPE.containing_type = _DEVICE
_DEVICELIST.fields_by_name['elements'].message_type = _DEVICE
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['DeviceList'] = _DEVICELIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'ubii.proto_v2.types.devices.device_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.Device)
  })
_sym_db.RegisterMessage(Device)

DeviceList = _reflection.GeneratedProtocolMessageType('DeviceList', (_message.Message,), {
  'DESCRIPTOR' : _DEVICELIST,
  '__module__' : 'ubii.proto_v2.types.devices.device_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.devices.DeviceList)
  })
_sym_db.RegisterMessage(DeviceList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.processing.lockstepProcessing_pb_plus import (
    LockstepProcessingReply,
    LockstepProcessingRequest,
)

from ubii.proto_v1.types.processing.processingModule_pb_plus import (
    ModuleIO,
    ProcessingMode,
    ProcessingModule,
    ProcessingModuleList,
)


__all__ = (
    "LockstepProcessingRequest",
    "LockstepProcessingReply",
    "ProcessingMode",
    "ModuleIO",
    "ProcessingModule",
    "ProcessingModuleList",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Enum,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "HandGestureType",
    }
)


class HandGestureType(Enum):
    REST = 0
    FINGERS_SPREAD = 1
    WAVE_IN = 2
    WAVE_OUT = 3
    FIST = 4
    DOUBLE_TAP = 5




"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
    RepeatedField,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Vector8",
        "Vector8List",
    }
)


class Vector8(Message):
    v0 = Field(
        DOUBLE,
        number=1,
    )
    v1 = Field(
        DOUBLE,
        number=2,
    )
    v2 = Field(
        DOUBLE,
        number=3,
    )
    v3 = Field(
        DOUBLE,
        number=4,
    )
    v4 = Field(
        DOUBLE,
        number=5,
    )
    v5 = Field(
        DOUBLE,
        number=6,
    )
    v6 = Field(
        DOUBLE,
        number=7,
    )
    v7 = Field(
        DOUBLE,
        number=8,
    )



class Vector8List(Message):
    elements = RepeatedField(
        Vector8,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    INT32,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "LockstepProcessingRequest",
        "LockstepProcessingReply",
    }
)


class LockstepProcessingRequest(Message):
    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )
    delta_time_ms = Field(
        INT32,
        number=3,
    )



class LockstepProcessingReply(Message):
    processing_module_ids = RepeatedField(
        STRING,
        number=1,
    )
    records = RepeatedField(
        TopicDataRecord,
        number=2,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/matrix3x2.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/matrix3x2.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1ubii/proto_v2/types/dataStructure/matrix3x2.proto\x12!ubii.proto_v2.types.dataStructure\"Y\n\tMatrix3x2\x12\x0b\n\x03m00\x18\x01 \x01(\x01\x12\x0b\n\x03m01\x18\x02 \x01(\x01\x12\x0b\n\x03m10\x18\x03 \x01(\x01\x12\x0b\n\x03m11\x18\x04 \x01(\x01\x12\x0b\n\x03m20\x18\x05 \x01(\x01\x12\x0b\n\x03m21\x18\x06 \x01(\x01\x62\x06proto3'
)




_MATRIX3X2 = _descriptor.Descriptor(
  name='Matrix3x2',
  full_name='ubii.proto_v2.types.dataStructure.Matrix3x2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='m00', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m00', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m01', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m01', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m10', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m10', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m11', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m11', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m20', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m20', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m21', full_name='ubii.proto_v2.types.dataStructure.Matrix3x2.m21', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=177,
)

DESCRIPTOR.message_types_by_name['Matrix3x2'] = _MATRIX3X2
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Matrix3x2 = _reflection.GeneratedProtocolMessageType('Matrix3x2', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX3X2,
  '__module__' : 'ubii.proto_v2.types.dataStructure.matrix3x2_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Matrix3x2)
  })
_sym_db.RegisterMessage(Matrix3x2)


# @@protoc_insertion_point(module_scope)



import os
from contextlib import contextmanager
from types import ModuleType
from typing import Type, NamedTuple, TypedDict, Dict, Any

import pytest
import json
from pathlib import Path


def pytest_addoption(parser, pluginmanager):
    parser.addini(name='data_dir',
                  default='./data',
                  help='Relative path to directory with test data.')


@pytest.fixture(scope='session')
def data_dir(pytestconfig) -> Path:
    data_dir_config_value = pytestconfig.getini('data_dir')
    data_dir = pytestconfig.rootpath / data_dir_config_value
    assert data_dir.exists(), f"Wrong data dir: {data_dir.resolve()} does not exist."
    yield data_dir


def write_json(file, data, indent=4, sort_keys=True, **kwargs):
    with file.open('w', encoding='utf-8') as stream:
        json.dump(data, fp=stream, sort_keys=sort_keys, indent=indent, **kwargs)


def load_json(file):
    with file.open('r') as f:
        try:
            return json.load(fp=f)
        except json.JSONDecodeError as e:
            return {}


@pytest.fixture(scope='session')
def make_file(data_dir):
    def touch(path: os.PathLike):
        path = Path(path)
        try:
            relative = path.relative_to(data_dir)
        except ValueError as e:
            relative = None

        if not relative:
            path = data_dir / path

        path.touch(exist_ok=True)
        return path

    yield touch


@pytest.fixture(scope='session')
def get_json_data(data_dir):

    def load_data_for_type(msg_type):
        files = data_dir.glob(f'{msg_type.lower()}.json')
        return {f: load_json(f) for f in files}

    yield load_data_for_type


@pytest.fixture
def write_json_data():
    backup = {}

    def write(file, data):
        nonlocal backup
        backup[file] = load_json(file)
        write_json(file, data)
        del backup[file]

    yield write

    if backup:
        for file, contents in backup.items():
            write_json(file, contents)

@pytest.fixture
def mock_proto_module():
    @contextmanager
    def ctx_manager(module: ModuleType):
        import ubii.proto
        old = ubii.proto.__proto_module__
        ubii.proto.__proto_module__ = module.__name__
        yield
        ubii.proto.__proto_module__ = old

    return ctx_manager

@pytest.fixture
def import_type(mock_proto_module):
    from ubii.util import import_type as _import_type
    import google.protobuf.wrappers_pb2 as wrappers

    def _import(data_type: str, module: ModuleType, force_wrapper=False):
        with mock_proto_module(module):
            if data_type.startswith('ubii.') or force_wrapper:
                return _import_type(data_type, reimport=True)
            else:
                return getattr(wrappers, f"{data_type.title()}Value")

    return _import


@pytest.fixture
def message_data(import_type, get_json_data, write_json_data, make_file, request):
    from ubii.proto_v1 import types as proto_plus
    from ubii.proto_v2 import types as proto_basic
    from proto.message import Message as ProtoPlusMessage
    from google.protobuf.message import Message as ProtoMessage
    from ubii.util import MSG_TYPES

    conversion_options = {
        'including_default_value_fields': True,
        'use_integers_for_enums': True,
    }

    class TestData(TypedDict):
        dict: Dict[str, Any]
        bytes: bytes
        json: str

    class Data(NamedTuple):
        proto_message: ProtoMessage
        plus_message: ProtoPlusMessage
        conversion_options: dict
        test_data: TestData

    msg_type = request.param
    data_file = Path(f"{msg_type.lower()}.json")
    basic_msg_type: Type[ProtoMessage] = import_type(getattr(MSG_TYPES, msg_type), proto_basic)
    proto_plus_type: Type[ProtoPlusMessage] = import_type(getattr(MSG_TYPES, msg_type), proto_plus, force_wrapper=True)

    if getattr(request.module, 'GENERATE_TEST_DATA', False):
        from google.protobuf.json_format import MessageToDict, MessageToJson

        file = make_file(data_file)
        message = basic_msg_type()
        data = {
            'dict': MessageToDict(message, **conversion_options),
            'bytes': message.SerializeToString(deterministic=True).decode('utf-8'),
            'json': MessageToJson(message, **conversion_options)
        }
        write_json_data(file, data)

    test_data = get_json_data(msg_type)

    for path, data in test_data.items():
        data['bytes'] = data['bytes'].encode('utf-8')
        proto_message = basic_msg_type.FromString(data['bytes'])
        plus_message = proto_plus_type.deserialize(data['bytes'])

        yield Data(proto_message=proto_message,
                   plus_message=plus_message,
                   conversion_options=conversion_options,
                   test_data=data)



#!/usr/bin/python

import sys, argparse
import os
import platform
import subprocess

from distutils.spawn import find_executable

# Find the Protocol Compiler.
protoc_local = os.path.join(os.path.dirname(__file__), '../external/bin/protoc')
protoc_local_windows = os.path.join(os.path.dirname(__file__), '../external/bin/protoc.exe')
if os.path.isfile(protoc_local):
    protoc = protoc_local
elif os.path.isfile(protoc_local_windows):
    protoc = protoc_local_windows
elif 'PROTOC' in os.environ and os.path.exists(os.environ['PROTOC']):
    protoc = os.environ['PROTOC']
else:
    protoc = find_executable("protoc")


def generateInits(pathToOutput):
   
    dirn = []
    start = True

    while len(dirn) != 0 or start:
        if start: p = pathToOutput 
        else: p = dirn.pop(0)
        
       
        for (dirpath, dirnames, filenames) in os.walk(p):
            dirn.extend([p+"/"+x for x in dirnames])
            filename = dirpath+'/__init__.py'
            #print(filename)
            os.makedirs(os.path.dirname(filename), exist_ok=True)
            if start != True:
                with open(filename, "w") as f:
                    pass
            break

        start = False


def getAllProtos(pathToProtos):

    dirn = []
    files = []
    start = True

    while len(dirn) != 0 or start:
        if start: p = pathToProtos 
        else: p = dirn.pop(0)

        start = False
        for (dirpath, dirnames, filenames) in os.walk(p):
            dirn.extend([p+"/"+x for x in dirnames])
            #destdir.extend([po+"/"+x for x in dirnames])
            files.extend(p+"/"+x for x in filenames)
            break
        
    return files

def generate_proto(source, pathToOutput, pathToProtos, includePath ,protocArg,require = True):
    """Invokes the Protocol Compiler to generate a _pb2.py from the given
    .proto file.  Does nothing if the output already exists and is newer than
    the input."""

    if not require and not os.path.exists(source):
        return

    #print('path to protos: '+pathToProtos)
    #print('path to output: '+pathToOutput)

    if not os.path.exists(source):
        sys.stderr.write("Can't find required file: %s\n" % source)
        sys.exit(-1)

    if protoc is None:
        sys.stderr.write(
            "protoc is not installed nor found in /external/bin.  Please compile it "
            "or install the binary package.\n")
        sys.exit(-1)

    protoc_command = [ protoc, "-I"+includePath, "-I.", "--"+protocArg+"_out="+pathToOutput, source ]
    print(protoc_command)
    if subprocess.call(protoc_command) != 0:
        sys.exit(-1)

def generateProtos(pathToOutput = './../dist/py', pathToProtos='./../src/proto', includePath='./../src' , protoc_arg='python'):
    re = getAllProtos(pathToProtos)
    #print(re)
    os.makedirs(pathToOutput, exist_ok=True)

    if protoc_arg == 'js':
        ### build js library
        pathToOutputLibrary = 'library=protobuf_library,binary:' + pathToOutput
        protoc_command = [ protoc, "-I"+includePath, "-I.", "--"+protoc_arg+"_out="+pathToOutputLibrary ]
        for i in re:
            protoc_command.append(i)
        #print(protoc_command)
        if subprocess.call(protoc_command) != 0:
            sys.exit(-1)

        # prepare output path for individual file compilation
        pathToOutput = 'import_style=commonjs,binary:' + pathToOutput

    for i in re:
        generate_proto(i, pathToOutput, pathToProtos, includePath, protoc_arg, False)

    print("compiled for " + protoc_arg)
    return pathToOutput


def chosen_option(args):
    file_directory = os.path.dirname(__file__)
    proto_src_directory = os.path.join(file_directory, '../src/proto')
    src_directory = os.path.join(file_directory, '../src')

    if args.opt == 'py' or args.opt == 'python':
        p = generateProtos(os.path.join(file_directory, '../dist/py'), proto_src_directory, src_directory, 'python')
        generateInits(p)
    elif args.opt == 'j' or args.opt == 'java':
        generateProtos(os.path.join(file_directory, '../dist/java'), proto_src_directory, src_directory, 'java')
    elif args.opt == 'js' or args.opt == 'javascript':
        generateProtos(os.path.join(file_directory, '../dist/js'), proto_src_directory, src_directory, 'js')
    elif args.opt == 'cs' or args.opt == 'csharp':
        generateProtos(os.path.join(file_directory, '../dist/cs'), proto_src_directory, src_directory, 'csharp')
    elif args.opt == 'cpp' or args.opt == 'cplusplus':
        generateProtos(os.path.join(file_directory, '../dist/cpp'), proto_src_directory, src_directory, 'cpp')
    elif args.opt == 'all':
        # python
        p = generateProtos(os.path.join(file_directory, '../dist/py'), proto_src_directory, src_directory, 'python')
        generateInits(p)
        # java
        generateProtos(os.path.join(file_directory, '../dist/java'), proto_src_directory, src_directory, 'java')
        # javascript
        generateProtos(os.path.join(file_directory, '../dist/js'), proto_src_directory, src_directory, 'js')
        # C#
        generateProtos(os.path.join(file_directory, '../dist/cs'), proto_src_directory, src_directory, 'csharp')
        # C++
        generateProtos(os.path.join(file_directory, '../dist/cpp'), proto_src_directory, src_directory, 'cpp')



def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--opt', type=str, default='all',
                        help='Supported options: [py] python, [j] java, [js] javascript, [cs] csharp, [all] all')

    args = parser.parse_args()
    sys.stdout.write(str(chosen_option(args)))


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/image.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ubii/proto_v2/types/dataStructure/image.proto\x12!ubii.proto_v2.types.dataStructure\"\xb0\x01\n\x07Image2D\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12J\n\x0b\x64\x61ta_format\x18\x03 \x01(\x0e\x32\x35.ubii.proto_v2.types.dataStructure.Image2D.DataFormat\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\",\n\nDataFormat\x12\t\n\x05GRAY8\x10\x00\x12\x08\n\x04RGB8\x10\x01\x12\t\n\x05RGBA8\x10\x02\"K\n\x0bImage2DList\x12<\n\x08\x65lements\x18\x01 \x03(\x0b\x32*.ubii.proto_v2.types.dataStructure.Image2Db\x06proto3'
)



_IMAGE2D_DATAFORMAT = _descriptor.EnumDescriptor(
  name='DataFormat',
  full_name='ubii.proto_v2.types.dataStructure.Image2D.DataFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRAY8', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGB8', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGBA8', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=217,
  serialized_end=261,
)
_sym_db.RegisterEnumDescriptor(_IMAGE2D_DATAFORMAT)


_IMAGE2D = _descriptor.Descriptor(
  name='Image2D',
  full_name='ubii.proto_v2.types.dataStructure.Image2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='ubii.proto_v2.types.dataStructure.Image2D.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='ubii.proto_v2.types.dataStructure.Image2D.height', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_format', full_name='ubii.proto_v2.types.dataStructure.Image2D.data_format', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ubii.proto_v2.types.dataStructure.Image2D.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE2D_DATAFORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=261,
)


_IMAGE2DLIST = _descriptor.Descriptor(
  name='Image2DList',
  full_name='ubii.proto_v2.types.dataStructure.Image2DList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.Image2DList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=338,
)

_IMAGE2D.fields_by_name['data_format'].enum_type = _IMAGE2D_DATAFORMAT
_IMAGE2D_DATAFORMAT.containing_type = _IMAGE2D
_IMAGE2DLIST.fields_by_name['elements'].message_type = _IMAGE2D
DESCRIPTOR.message_types_by_name['Image2D'] = _IMAGE2D
DESCRIPTOR.message_types_by_name['Image2DList'] = _IMAGE2DLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image2D = _reflection.GeneratedProtocolMessageType('Image2D', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE2D,
  '__module__' : 'ubii.proto_v2.types.dataStructure.image_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Image2D)
  })
_sym_db.RegisterMessage(Image2D)

Image2DList = _reflection.GeneratedProtocolMessageType('Image2DList', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE2DLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.image_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Image2DList)
  })
_sym_db.RegisterMessage(Image2DList)


# @@protoc_insertion_point(module_scope)



import re
import pytest
from ubii.util import MSG_TYPES

GENERATE_TEST_DATA = True


@pytest.mark.parametrize('message_data', MSG_TYPES, indirect=True)
class TestTranslators:

    def test_from_bytes(self, message_data):
        wrapped = type(message_data.plus_message).pb(message_data.plus_message)
        assert message_data.proto_message == wrapped

    def test_from_json(self, message_data):
        assert message_data.message == message_data.proto_plus_type(message_data.test_data['json'])

    def test_from_dict(self, message_data):
        assert message_data.message == message_data.proto_plus_message.from_dict(message_data.test_data['dict'])

    def test_to_dict(self, message_data):
        assert message_data.test_data['dict'] == message_data.proto_plus_message.to_dict(message_data.message)

    def test_to_json(self, message_data):
        assert message_data.test_data['json'] == message_data.translator.to_json(message_data.proto_plus_message, **conversion_options)

    def test_convert_to_message(self, message_data):
        list_values = list(message_data.test_data.values())

        # check all items individually
        assert all(message_data.message == message_data.translator.convert_to_message(obj) for obj in message_data.test_data.values())

        # also check if List conversion works
        assert [message_data.message] * len(list_values) == message_data.translator.convert_to_message(list_values)

    def test_create(self, message_data):
        test_dict: dict = message_data.test_data['dict']
        assert message_data.message == message_data.translator.create(**test_dict)

    def test_validate(self, message_data, request):
        if 'protoplus' in request.node.name:
            pytest.xfail("Validation is not supported for proto plus")

        validate = message_data.translator.validate

        assert message_data.message == validate(message_data.message)
        assert all(message_data.message == validate(message_data.test_data[serializable]) for serializable in ['dict', 'json'])
        snake_case_dict = {re.sub('([A-Z]+)', r'_\1', k).lower(): v for k, v in message_data.test_data['dict'].items()}
        assert message_data.message == validate(snake_case_dict)





import json
from abc import ABCMeta
from functools import partial
from importlib.metadata import distribution, version, PackageNotFoundError
from json import JSONEncoder
from warnings import warn

import proto
from google.protobuf.json_format import MessageToDict as _MessageToDict
from google.protobuf.message import Message as GoogleProtoMessage
from more_itertools import take, pad_none
from proto.message import Message as ProtoMessage, MessageMeta
from proto.fields import Field as ProtoField

from ubii.proto_v1.types import (
    Client,
    ClientList,
    ButtonEventType,
    HandGestureType,
    Color,
    Image2D,
    Image2DList,
    KeyEvent,
    StringList,
    DoubleList,
    FloatList,
    BoolList,
    Int32List,
    Matrix3x2,
    Matrix4x4,
    MouseEvent,
    MyoEvent,
    Object2D,
    Object2DList,
    Object3D,
    Object3DList,
    Pose2D,
    Pose3D,
    Quaternion,
    QuaternionList,
    TouchEvent,
    TouchEventList,
    Vector2,
    Vector2List,
    Vector3,
    Vector3List,
    Vector4,
    Vector4List,
    Vector8,
    Vector8List,
    Component,
    ComponentList,
    Device,
    DeviceList,
    TopicDemux,
    TopicDemuxList,
    TopicMux,
    TopicMuxList,
    Error,
    ErrorList,
    Success,
    SuccessList,
    LockstepProcessingRequest,
    LockstepProcessingReply,
    ProcessingMode,
    ModuleIO,
    ProcessingModule,
    ProcessingModuleList,
    Constants,
    Server,
    Service,
    ServiceList,
    ServiceReply,
    ServiceRequest,
    TopicSubscription,
    SessionStatus,
    TopicInputMapping,
    TopicInputMappingList,
    TopicOutputMapping,
    TopicOutputMappingList,
    IOMapping,
    IOMappingList,
    Session,
    SessionList,
    Timestamp,
    TopicData,
    TopicDataRecord,
    TopicDataRecordList,
)

__proto_types__ = (
    "Client",
    "ClientList",
    "ButtonEventType",
    "HandGestureType",
    "Color",
    "Image2D",
    "Image2DList",
    "KeyEvent",
    "StringList",
    "DoubleList",
    "FloatList",
    "BoolList",
    "Int32List",
    "Matrix3x2",
    "Matrix4x4",
    "MouseEvent",
    "MyoEvent",
    "Object2D",
    "Object2DList",
    "Object3D",
    "Object3DList",
    "Pose2D",
    "Pose3D",
    "Quaternion",
    "QuaternionList",
    "TouchEvent",
    "TouchEventList",
    "Vector2",
    "Vector2List",
    "Vector3",
    "Vector3List",
    "Vector4",
    "Vector4List",
    "Vector8",
    "Vector8List",
    "Component",
    "ComponentList",
    "Device",
    "DeviceList",
    "TopicDemux",
    "TopicDemuxList",
    "TopicMux",
    "TopicMuxList",
    "Error",
    "ErrorList",
    "Success",
    "SuccessList",
    "LockstepProcessingRequest",
    "LockstepProcessingReply",
    "ProcessingMode",
    "ModuleIO",
    "ProcessingModule",
    "ProcessingModuleList",
    "Constants",
    "Server",
    "Service",
    "ServiceList",
    "ServiceReply",
    "ServiceRequest",
    "TopicSubscription",
    "SessionStatus",
    "TopicInputMapping",
    "TopicInputMappingList",
    "TopicOutputMapping",
    "TopicOutputMappingList",
    "IOMapping",
    "IOMappingList",
    "Session",
    "SessionList",
    "Timestamp",
    "TopicData",
    "TopicDataRecord",
    "TopicDataRecordList",
)

__all__ = __proto_types__ + (
    "ProtoMeta",
    "ProtoEncoder",
    "ProtoMessage",
    "ProtoField",
    "serialize",
)

_pkg_name = 'ubii-message-formats'
try:
    __version__ = version(_pkg_name)
    __proto_module__, __proto_package__ = take(2, pad_none(distribution(_pkg_name)
                                                           .read_text('proto_package.txt')
                                                           .split('='))
                                               )
except PackageNotFoundError as e:
    raise PackageNotFoundError(f"{_pkg_name} is not found, did the package name change?") from e
del _pkg_name

__protobuf__ = proto.module(
    package=__proto_package__ or __proto_module__,
    manifest=set(__proto_types__)
)

if __proto_package__ is None:
    warn("package is not set in proto_package.txt from ubii-message-formats."
         " This is unexpected, make sure you compiled the ubii-message-formats with a recent"
         " version of the proto-plus-plugin. For more info resort to the documentation of the"
         " ubii-message-formats plugin")


class ProtoEncoder(JSONEncoder):
    """
    Custom encoder to convert Protobuf Messages and Proto-Plus Messages to valid json
    """
    format_options = {
        "use_integers_for_enums": True,
        "including_default_value_fields": True,
        "preserving_proto_field_name": False,
    }

    def default(self, o):
        if isinstance(o, ProtoMessage):
            return type(o).to_dict(o, **self.format_options)

        if isinstance(o, GoogleProtoMessage):
            return _MessageToDict(o, **self.format_options)

        return JSONEncoder.default(self, o)


class ProtoMeta(ABCMeta, MessageMeta):
    def __new__(mcs, name, bases, attrs):
        message_bases = [b for b in bases if isinstance(b, MessageMeta)]
        if len(message_bases) != 1:
            raise NotImplemented(f"Can't subclass with {len(message_bases)} Message parent classes")

        parent: MessageMeta = message_bases[0]
        cls = super().__new__(mcs, name, bases, {**attrs, **parent.meta.fields})
        cls.meta._pb = parent.pb()
        return cls


serialize = partial(json.dumps, cls=ProtoEncoder)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/mouseEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import buttonEventType_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_buttonEventType__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/mouseEvent.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2ubii/proto_v2/types/dataStructure/mouseEvent.proto\x12!ubii.proto_v2.types.dataStructure\x1a\x37ubii/proto_v2/types/dataStructure/buttonEventType.proto\"^\n\nMouseEvent\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.ubii.proto_v2.types.dataStructure.ButtonEventType\x12\x0e\n\x06\x62utton\x18\x02 \x01(\x05\x62\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_buttonEventType__pb2.DESCRIPTOR,])




_MOUSEEVENT = _descriptor.Descriptor(
  name='MouseEvent',
  full_name='ubii.proto_v2.types.dataStructure.MouseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ubii.proto_v2.types.dataStructure.MouseEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='ubii.proto_v2.types.dataStructure.MouseEvent.button', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=240,
)

_MOUSEEVENT.fields_by_name['type'].enum_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_buttonEventType__pb2._BUTTONEVENTTYPE
DESCRIPTOR.message_types_by_name['MouseEvent'] = _MOUSEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MouseEvent = _reflection.GeneratedProtocolMessageType('MouseEvent', (_message.Message,), {
  'DESCRIPTOR' : _MOUSEEVENT,
  '__module__' : 'ubii.proto_v2.types.dataStructure.mouseEvent_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.MouseEvent)
  })
_sym_db.RegisterMessage(MouseEvent)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/servers/server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/servers/server.proto',
  package='ubii.proto_v2.types.servers',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(ubii/proto_v2/types/servers/server.proto\x12\x1bubii.proto_v2.types.servers\"\xce\x01\n\x06Server\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bip_ethernet\x18\x03 \x01(\t\x12\x0f\n\x07ip_wlan\x18\x04 \x01(\t\x12\x18\n\x10port_service_zmq\x18\x05 \x01(\t\x12\x19\n\x11port_service_rest\x18\x06 \x01(\t\x12\x1b\n\x13port_topic_data_zmq\x18\x07 \x01(\t\x12\x1a\n\x12port_topic_data_ws\x18\x08 \x01(\t\x12\x16\n\x0e\x63onstants_json\x18\t \x01(\tb\x06proto3'
)




_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='ubii.proto_v2.types.servers.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.servers.Server.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.servers.Server.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_ethernet', full_name='ubii.proto_v2.types.servers.Server.ip_ethernet', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_wlan', full_name='ubii.proto_v2.types.servers.Server.ip_wlan', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_service_zmq', full_name='ubii.proto_v2.types.servers.Server.port_service_zmq', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_service_rest', full_name='ubii.proto_v2.types.servers.Server.port_service_rest', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_topic_data_zmq', full_name='ubii.proto_v2.types.servers.Server.port_topic_data_zmq', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_topic_data_ws', full_name='ubii.proto_v2.types.servers.Server.port_topic_data_ws', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constants_json', full_name='ubii.proto_v2.types.servers.Server.constants_json', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['Server'] = _SERVER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
  'DESCRIPTOR' : _SERVER,
  '__module__' : 'ubii.proto_v2.types.servers.server_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.servers.Server)
  })
_sym_db.RegisterMessage(Server)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.services.request.topicSubscription_pb_plus import (
    TopicSubscription,
)


__all__ = (
    "TopicSubscription",
)


"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.sessions.ioMappings_pb_plus import (
    IOMapping,
    IOMappingList,
    TopicInputMapping,
    TopicInputMappingList,
    TopicOutputMapping,
    TopicOutputMappingList,
)

from ubii.proto_v1.types.sessions.session_pb_plus import (
    Session,
    SessionList,
    SessionStatus,
)


__all__ = (
    "SessionStatus",
    "TopicInputMapping",
    "TopicInputMappingList",
    "TopicOutputMapping",
    "TopicOutputMappingList",
    "IOMapping",
    "IOMappingList",
    "Session",
    "SessionList",
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/object2d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ubii.proto_v2.types.dataStructure import pose2d_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2
from ubii.proto_v2.types.dataStructure import vector2_pb2 as ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/object2d.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0ubii/proto_v2/types/dataStructure/object2d.proto\x12!ubii.proto_v2.types.dataStructure\x1a.ubii/proto_v2/types/dataStructure/pose2d.proto\x1a/ubii/proto_v2/types/dataStructure/vector2.proto\"\xa1\x01\n\x08Object2D\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x04pose\x18\x02 \x01(\x0b\x32).ubii.proto_v2.types.dataStructure.Pose2D\x12\x38\n\x04size\x18\x03 \x01(\x0b\x32*.ubii.proto_v2.types.dataStructure.Vector2\x12\x16\n\x0euser_data_json\x18\x04 \x01(\t\"M\n\x0cObject2DList\x12=\n\x08\x65lements\x18\x01 \x03(\x0b\x32+.ubii.proto_v2.types.dataStructure.Object2Db\x06proto3'
  ,
  dependencies=[ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2.DESCRIPTOR,ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2.DESCRIPTOR,])




_OBJECT2D = _descriptor.Descriptor(
  name='Object2D',
  full_name='ubii.proto_v2.types.dataStructure.Object2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.dataStructure.Object2D.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='ubii.proto_v2.types.dataStructure.Object2D.pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='ubii.proto_v2.types.dataStructure.Object2D.size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data_json', full_name='ubii.proto_v2.types.dataStructure.Object2D.user_data_json', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=346,
)


_OBJECT2DLIST = _descriptor.Descriptor(
  name='Object2DList',
  full_name='ubii.proto_v2.types.dataStructure.Object2DList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.dataStructure.Object2DList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=425,
)

_OBJECT2D.fields_by_name['pose'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_pose2d__pb2._POSE2D
_OBJECT2D.fields_by_name['size'].message_type = ubii_dot_proto__v2_dot_types_dot_dataStructure_dot_vector2__pb2._VECTOR2
_OBJECT2DLIST.fields_by_name['elements'].message_type = _OBJECT2D
DESCRIPTOR.message_types_by_name['Object2D'] = _OBJECT2D
DESCRIPTOR.message_types_by_name['Object2DList'] = _OBJECT2DLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Object2D = _reflection.GeneratedProtocolMessageType('Object2D', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT2D,
  '__module__' : 'ubii.proto_v2.types.dataStructure.object2d_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Object2D)
  })
_sym_db.RegisterMessage(Object2D)

Object2DList = _reflection.GeneratedProtocolMessageType('Object2DList', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT2DLIST,
  '__module__' : 'ubii.proto_v2.types.dataStructure.object2d_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Object2DList)
  })
_sym_db.RegisterMessage(Object2DList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    BOOL,
    DOUBLE,
    FLOAT,
    INT32,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "StringList",
        "DoubleList",
        "FloatList",
        "BoolList",
        "Int32List",
    }
)


class StringList(Message):
    elements = RepeatedField(
        STRING,
        number=1,
    )



class DoubleList(Message):
    elements = RepeatedField(
        DOUBLE,
        number=1,
    )



class FloatList(Message):
    elements = RepeatedField(
        FLOAT,
        number=1,
    )



class BoolList(Message):
    elements = RepeatedField(
        BOOL,
        number=1,
    )



class Int32List(Message):
    elements = RepeatedField(
        INT32,
        number=1,
    )





"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    FLOAT,
    Field,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Pose2D",
    }
)


class Pose2D(Message):
    position = Field(
        Vector2,
        number=1,
    )
    direction = Field(
        Vector2,
        number=2,
        oneof='orientation',
    )
    angle = Field(
        FLOAT,
        number=3,
        oneof='orientation',
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/dataStructure/matrix4x4.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/dataStructure/matrix4x4.proto',
  package='ubii.proto_v2.types.dataStructure',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1ubii/proto_v2/types/dataStructure/matrix4x4.proto\x12!ubii.proto_v2.types.dataStructure\"\xdb\x01\n\tMatrix4x4\x12\x0b\n\x03m00\x18\x01 \x01(\x01\x12\x0b\n\x03m01\x18\x02 \x01(\x01\x12\x0b\n\x03m02\x18\x03 \x01(\x01\x12\x0b\n\x03m03\x18\x04 \x01(\x01\x12\x0b\n\x03m10\x18\x05 \x01(\x01\x12\x0b\n\x03m11\x18\x06 \x01(\x01\x12\x0b\n\x03m12\x18\x07 \x01(\x01\x12\x0b\n\x03m13\x18\x08 \x01(\x01\x12\x0b\n\x03m20\x18\t \x01(\x01\x12\x0b\n\x03m21\x18\n \x01(\x01\x12\x0b\n\x03m22\x18\x0b \x01(\x01\x12\x0b\n\x03m23\x18\x0c \x01(\x01\x12\x0b\n\x03m30\x18\r \x01(\x01\x12\x0b\n\x03m31\x18\x0e \x01(\x01\x12\x0b\n\x03m32\x18\x0f \x01(\x01\x12\x0b\n\x03m33\x18\x10 \x01(\x01\x62\x06proto3'
)




_MATRIX4X4 = _descriptor.Descriptor(
  name='Matrix4x4',
  full_name='ubii.proto_v2.types.dataStructure.Matrix4x4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='m00', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m00', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m01', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m01', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m02', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m02', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m03', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m03', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m10', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m10', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m11', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m11', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m12', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m12', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m13', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m13', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m20', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m20', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m21', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m21', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m22', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m22', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m23', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m23', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m30', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m30', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m31', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m31', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m32', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m32', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m33', full_name='ubii.proto_v2.types.dataStructure.Matrix4x4.m33', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=308,
)

DESCRIPTOR.message_types_by_name['Matrix4x4'] = _MATRIX4X4
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Matrix4x4 = _reflection.GeneratedProtocolMessageType('Matrix4x4', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX4X4,
  '__module__' : 'ubii.proto_v2.types.dataStructure.matrix4x4_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.dataStructure.Matrix4x4)
  })
_sym_db.RegisterMessage(Matrix4x4)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    DOUBLE,
    Field,
)

from proto.message import (
    Message,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Matrix3x2",
    }
)


class Matrix3x2(Message):
    m00 = Field(
        DOUBLE,
        number=1,
    )
    m01 = Field(
        DOUBLE,
        number=2,
    )
    m10 = Field(
        DOUBLE,
        number=3,
    )
    m11 = Field(
        DOUBLE,
        number=4,
    )
    m20 = Field(
        DOUBLE,
        number=5,
    )
    m21 = Field(
        DOUBLE,
        number=6,
    )





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/processing/processingModule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/processing/processingModule.proto',
  package='ubii.proto_v2.types.processing',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5ubii/proto_v2/types/processing/processingModule.proto\x12\x1eubii.proto_v2.types.processing\"\xa1\x03\n\x0eProcessingMode\x12M\n\tfrequency\x18\x01 \x01(\x0b\x32\x38.ubii.proto_v2.types.processing.ProcessingMode.FrequencyH\x00\x12K\n\x08lockstep\x18\x02 \x01(\x0b\x32\x37.ubii.proto_v2.types.processing.ProcessingMode.LockstepH\x00\x12Y\n\x10trigger_on_input\x18\x03 \x01(\x0b\x32=.ubii.proto_v2.types.processing.ProcessingMode.TriggerOnInputH\x00\x1a\x1a\n\tFrequency\x12\r\n\x05hertz\x18\x01 \x01(\x05\x1a,\n\x08Lockstep\x12 \n\x18process_request_endpoint\x18\x01 \x01(\t\x1a\x46\n\x0eTriggerOnInput\x12\x14\n\x0cmin_delay_ms\x18\x01 \x01(\x05\x12\x1e\n\x16\x61ll_inputs_need_update\x18\x02 \x01(\x08\x42\x06\n\x04mode\"9\n\x08ModuleIO\x12\x15\n\rinternal_name\x18\x01 \x01(\t\x12\x16\n\x0emessage_format\x18\x02 \x01(\t\"\xe7\x05\n\x10ProcessingModule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61uthors\x18\x03 \x03(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07node_id\x18\x06 \x01(\t\x12\x12\n\nsession_id\x18\x07 \x01(\t\x12G\n\x06status\x18\x08 \x01(\x0e\x32\x37.ubii.proto_v2.types.processing.ProcessingModule.Status\x12G\n\x0fprocessing_mode\x18\t \x01(\x0b\x32..ubii.proto_v2.types.processing.ProcessingMode\x12\x38\n\x06inputs\x18\n \x03(\x0b\x32(.ubii.proto_v2.types.processing.ModuleIO\x12\x39\n\x07outputs\x18\x0b \x03(\x0b\x32(.ubii.proto_v2.types.processing.ModuleIO\x12K\n\x08language\x18\x0c \x01(\x0e\x32\x39.ubii.proto_v2.types.processing.ProcessingModule.Language\x12!\n\x19on_processing_stringified\x18\r \x01(\t\x12\x1e\n\x16on_created_stringified\x18\x0e \x01(\t\x12\x1d\n\x15on_halted_stringified\x18\x0f \x01(\t\x12 \n\x18on_destroyed_stringified\x18\x10 \x01(\t\"Q\n\x06Status\x12\x0f\n\x0bINITIALIZED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\n\n\x06HALTED\x10\x03\x12\r\n\tDESTROYED\x10\x04\"5\n\x08Language\x12\x07\n\x03\x43PP\x10\x00\x12\x06\n\x02PY\x10\x01\x12\x06\n\x02JS\x10\x02\x12\x06\n\x02\x43S\x10\x03\x12\x08\n\x04JAVA\x10\x04\"Z\n\x14ProcessingModuleList\x12\x42\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x30.ubii.proto_v2.types.processing.ProcessingModuleb\x06proto3'
)



_PROCESSINGMODULE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ubii.proto_v2.types.processing.ProcessingModule.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HALTED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESTROYED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1176,
  serialized_end=1257,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODULE_STATUS)

_PROCESSINGMODULE_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='ubii.proto_v2.types.processing.ProcessingModule.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CPP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JAVA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1259,
  serialized_end=1312,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODULE_LANGUAGE)


_PROCESSINGMODE_FREQUENCY = _descriptor.Descriptor(
  name='Frequency',
  full_name='ubii.proto_v2.types.processing.ProcessingMode.Frequency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hertz', full_name='ubii.proto_v2.types.processing.ProcessingMode.Frequency.hertz', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=381,
)

_PROCESSINGMODE_LOCKSTEP = _descriptor.Descriptor(
  name='Lockstep',
  full_name='ubii.proto_v2.types.processing.ProcessingMode.Lockstep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='process_request_endpoint', full_name='ubii.proto_v2.types.processing.ProcessingMode.Lockstep.process_request_endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=427,
)

_PROCESSINGMODE_TRIGGERONINPUT = _descriptor.Descriptor(
  name='TriggerOnInput',
  full_name='ubii.proto_v2.types.processing.ProcessingMode.TriggerOnInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_delay_ms', full_name='ubii.proto_v2.types.processing.ProcessingMode.TriggerOnInput.min_delay_ms', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_inputs_need_update', full_name='ubii.proto_v2.types.processing.ProcessingMode.TriggerOnInput.all_inputs_need_update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=499,
)

_PROCESSINGMODE = _descriptor.Descriptor(
  name='ProcessingMode',
  full_name='ubii.proto_v2.types.processing.ProcessingMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='ubii.proto_v2.types.processing.ProcessingMode.frequency', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep', full_name='ubii.proto_v2.types.processing.ProcessingMode.lockstep', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_on_input', full_name='ubii.proto_v2.types.processing.ProcessingMode.trigger_on_input', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROCESSINGMODE_FREQUENCY, _PROCESSINGMODE_LOCKSTEP, _PROCESSINGMODE_TRIGGERONINPUT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mode', full_name='ubii.proto_v2.types.processing.ProcessingMode.mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90,
  serialized_end=507,
)


_MODULEIO = _descriptor.Descriptor(
  name='ModuleIO',
  full_name='ubii.proto_v2.types.processing.ModuleIO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='internal_name', full_name='ubii.proto_v2.types.processing.ModuleIO.internal_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_format', full_name='ubii.proto_v2.types.processing.ModuleIO.message_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=566,
)


_PROCESSINGMODULE = _descriptor.Descriptor(
  name='ProcessingModule',
  full_name='ubii.proto_v2.types.processing.ProcessingModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ubii.proto_v2.types.processing.ProcessingModule.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ubii.proto_v2.types.processing.ProcessingModule.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authors', full_name='ubii.proto_v2.types.processing.ProcessingModule.authors', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ubii.proto_v2.types.processing.ProcessingModule.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ubii.proto_v2.types.processing.ProcessingModule.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ubii.proto_v2.types.processing.ProcessingModule.node_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='ubii.proto_v2.types.processing.ProcessingModule.session_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='ubii.proto_v2.types.processing.ProcessingModule.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_mode', full_name='ubii.proto_v2.types.processing.ProcessingModule.processing_mode', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='ubii.proto_v2.types.processing.ProcessingModule.inputs', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='ubii.proto_v2.types.processing.ProcessingModule.outputs', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='ubii.proto_v2.types.processing.ProcessingModule.language', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_processing_stringified', full_name='ubii.proto_v2.types.processing.ProcessingModule.on_processing_stringified', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_created_stringified', full_name='ubii.proto_v2.types.processing.ProcessingModule.on_created_stringified', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_halted_stringified', full_name='ubii.proto_v2.types.processing.ProcessingModule.on_halted_stringified', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_destroyed_stringified', full_name='ubii.proto_v2.types.processing.ProcessingModule.on_destroyed_stringified', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSINGMODULE_STATUS,
    _PROCESSINGMODULE_LANGUAGE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=1312,
)


_PROCESSINGMODULELIST = _descriptor.Descriptor(
  name='ProcessingModuleList',
  full_name='ubii.proto_v2.types.processing.ProcessingModuleList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.processing.ProcessingModuleList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1314,
  serialized_end=1404,
)

_PROCESSINGMODE_FREQUENCY.containing_type = _PROCESSINGMODE
_PROCESSINGMODE_LOCKSTEP.containing_type = _PROCESSINGMODE
_PROCESSINGMODE_TRIGGERONINPUT.containing_type = _PROCESSINGMODE
_PROCESSINGMODE.fields_by_name['frequency'].message_type = _PROCESSINGMODE_FREQUENCY
_PROCESSINGMODE.fields_by_name['lockstep'].message_type = _PROCESSINGMODE_LOCKSTEP
_PROCESSINGMODE.fields_by_name['trigger_on_input'].message_type = _PROCESSINGMODE_TRIGGERONINPUT
_PROCESSINGMODE.oneofs_by_name['mode'].fields.append(
  _PROCESSINGMODE.fields_by_name['frequency'])
_PROCESSINGMODE.fields_by_name['frequency'].containing_oneof = _PROCESSINGMODE.oneofs_by_name['mode']
_PROCESSINGMODE.oneofs_by_name['mode'].fields.append(
  _PROCESSINGMODE.fields_by_name['lockstep'])
_PROCESSINGMODE.fields_by_name['lockstep'].containing_oneof = _PROCESSINGMODE.oneofs_by_name['mode']
_PROCESSINGMODE.oneofs_by_name['mode'].fields.append(
  _PROCESSINGMODE.fields_by_name['trigger_on_input'])
_PROCESSINGMODE.fields_by_name['trigger_on_input'].containing_oneof = _PROCESSINGMODE.oneofs_by_name['mode']
_PROCESSINGMODULE.fields_by_name['status'].enum_type = _PROCESSINGMODULE_STATUS
_PROCESSINGMODULE.fields_by_name['processing_mode'].message_type = _PROCESSINGMODE
_PROCESSINGMODULE.fields_by_name['inputs'].message_type = _MODULEIO
_PROCESSINGMODULE.fields_by_name['outputs'].message_type = _MODULEIO
_PROCESSINGMODULE.fields_by_name['language'].enum_type = _PROCESSINGMODULE_LANGUAGE
_PROCESSINGMODULE_STATUS.containing_type = _PROCESSINGMODULE
_PROCESSINGMODULE_LANGUAGE.containing_type = _PROCESSINGMODULE
_PROCESSINGMODULELIST.fields_by_name['elements'].message_type = _PROCESSINGMODULE
DESCRIPTOR.message_types_by_name['ProcessingMode'] = _PROCESSINGMODE
DESCRIPTOR.message_types_by_name['ModuleIO'] = _MODULEIO
DESCRIPTOR.message_types_by_name['ProcessingModule'] = _PROCESSINGMODULE
DESCRIPTOR.message_types_by_name['ProcessingModuleList'] = _PROCESSINGMODULELIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingMode = _reflection.GeneratedProtocolMessageType('ProcessingMode', (_message.Message,), {

  'Frequency' : _reflection.GeneratedProtocolMessageType('Frequency', (_message.Message,), {
    'DESCRIPTOR' : _PROCESSINGMODE_FREQUENCY,
    '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
    # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingMode.Frequency)
    })
  ,

  'Lockstep' : _reflection.GeneratedProtocolMessageType('Lockstep', (_message.Message,), {
    'DESCRIPTOR' : _PROCESSINGMODE_LOCKSTEP,
    '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
    # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingMode.Lockstep)
    })
  ,

  'TriggerOnInput' : _reflection.GeneratedProtocolMessageType('TriggerOnInput', (_message.Message,), {
    'DESCRIPTOR' : _PROCESSINGMODE_TRIGGERONINPUT,
    '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
    # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingMode.TriggerOnInput)
    })
  ,
  'DESCRIPTOR' : _PROCESSINGMODE,
  '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingMode)
  })
_sym_db.RegisterMessage(ProcessingMode)
_sym_db.RegisterMessage(ProcessingMode.Frequency)
_sym_db.RegisterMessage(ProcessingMode.Lockstep)
_sym_db.RegisterMessage(ProcessingMode.TriggerOnInput)

ModuleIO = _reflection.GeneratedProtocolMessageType('ModuleIO', (_message.Message,), {
  'DESCRIPTOR' : _MODULEIO,
  '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ModuleIO)
  })
_sym_db.RegisterMessage(ModuleIO)

ProcessingModule = _reflection.GeneratedProtocolMessageType('ProcessingModule', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGMODULE,
  '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingModule)
  })
_sym_db.RegisterMessage(ProcessingModule)

ProcessingModuleList = _reflection.GeneratedProtocolMessageType('ProcessingModuleList', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGMODULELIST,
  '__module__' : 'ubii.proto_v2.types.processing.processingModule_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.processing.ProcessingModuleList)
  })
_sym_db.RegisterMessage(ProcessingModuleList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
from ubii.proto_v1.types.topicData.timestamp_pb_plus import (
    Timestamp,
)

from ubii.proto_v1.types.topicData.topicDataRecord_pb_plus import (
    TopicDataRecord,
    TopicDataRecordList,
)

from ubii.proto_v1.types.topicData.topicData_pb_plus import (
    TopicData,
)


__all__ = (
    "Timestamp",
    "TopicData",
    "TopicDataRecord",
    "TopicDataRecordList",
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ubii/proto_v2/types/general/success.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ubii/proto_v2/types/general/success.proto',
  package='ubii.proto_v2.types.general',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)ubii/proto_v2/types/general/success.proto\x12\x1bubii.proto_v2.types.general\")\n\x07Success\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n\x0bSuccessList\x12\x36\n\x08\x65lements\x18\x01 \x03(\x0b\x32$.ubii.proto_v2.types.general.Successb\x06proto3'
)




_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='ubii.proto_v2.types.general.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='ubii.proto_v2.types.general.Success.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='ubii.proto_v2.types.general.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=74,
  serialized_end=115,
)


_SUCCESSLIST = _descriptor.Descriptor(
  name='SuccessList',
  full_name='ubii.proto_v2.types.general.SuccessList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='ubii.proto_v2.types.general.SuccessList.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=186,
)

_SUCCESSLIST.fields_by_name['elements'].message_type = _SUCCESS
DESCRIPTOR.message_types_by_name['Success'] = _SUCCESS
DESCRIPTOR.message_types_by_name['SuccessList'] = _SUCCESSLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Success = _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESS,
  '__module__' : 'ubii.proto_v2.types.general.success_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.general.Success)
  })
_sym_db.RegisterMessage(Success)

SuccessList = _reflection.GeneratedProtocolMessageType('SuccessList', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESSLIST,
  '__module__' : 'ubii.proto_v2.types.general.success_pb2'
  # @@protoc_insertion_point(class_scope:ubii.proto_v2.types.general.SuccessList)
  })
_sym_db.RegisterMessage(SuccessList)


# @@protoc_insertion_point(module_scope)



"""
@generated by codestare-proto-plus.  Do not edit manually!
isort:skip_file
"""
import proto
from proto import (
    Field,
    RepeatedField,
    STRING,
)

from proto.message import (
    Message,
)

from ubii.proto_v1.types.dataStructure.pose2d_pb_plus import (
    Pose2D,
)

from ubii.proto_v1.types.dataStructure.vector2_pb_plus import (
    Vector2,
)


__protobuf__ = proto.module(
    package="ubii.interact.v1",
    manifest={
        "Object2D",
        "Object2DList",
    }
)


class Object2D(Message):
    id = Field(
        STRING,
        number=1,
    )
    pose = Field(
        Pose2D,
        number=2,
    )
    size = Field(
        Vector2,
        number=3,
    )
    user_data_json = Field(
        STRING,
        number=4,
    )



class Object2DList(Message):
    elements = RepeatedField(
        Object2D,
        number=1,
    )


